@@ -1,6 +1,7 @@
 #' @title Read map file
 #' @description Read in the marker map  data. 
-#' @param filename contains the name of the map file. The file name needs to be in quotes.
+#' @param filename contains the name of the map file. The file name needs to be in quotes. If the file is not in the working directory, then the full path 
+#' to the file is required. 
 #' @param csv   a logical value. When \code{TRUE}, a csv file format is assumed. When \code{FALSE}, a space separated format is assumed. 
 #' @param header   a logical value. When \code{TRUE}, the first row of the file contains the column headings. 
 #' @details
@@ -76,11 +77,11 @@ message(" First 5 markers of the map file are \n")
 
 if(nrow(map) > 5){
   for(ii in 1:5){
-  message(cat(paste(map[ii,], sep=" ")))
+  message(paste(map[ii,], collapse=" "))
   }
 } else {
   for(ii in 1:nrow(map) ){
-  message(cat(paste(map[ii,], sep=" ")))
+  message(paste(map[ii,], collapse=" "))
   }
 }
 
