@@ -1,11 +1,12 @@
-.form_results <- function(trait, selected_loci, map,  fformula, indxNA,
-                           ncpu, availmemGb, quiet,  extBIC, gamma )
+.form_results <- function(trait, selected_loci,   fformula, indxNA_pheno, indxNA_geno,
+                           ncpu, availmemGb, quiet,  extBIC, gamma, geno, pheno, map, Zmat )
 {
   ## internal function - used by AM for forming the results object
   if (length(selected_loci) > 1){
    sigres <- list(trait=trait,
                     fformula = fformula,
-                    indxNA = indxNA,
+                    indxNA_pheno = indxNA_pheno,
+                    indxNA_geno = indxNA_geno,
                     Mrk=map[[1]][selected_loci],
                     Chr=map[[2]][selected_loci],
                     Pos=map[[3]][selected_loci],
@@ -14,11 +15,16 @@
                     availmemGb=availmemGb,
                     quiet=quiet,
                     extBIC=extBIC,
-                    gamma=gamma)
+                    gamma=gamma,
+                    geno=geno,
+                    pheno=pheno,
+                    map=map,
+                    Zmat=Zmat)
   } else {
    sigres <- list(trait=trait,
                     fformula = fformula,
-                    indxNA = indxNA,
+                    indxNA_pheno = indxNA_pheno,
+                    indxNA_geno = indxNA_geno,
                     Mrk=NA,
                     Chr=NA,
                     Pos=NA,
@@ -27,7 +33,11 @@
                     availmemGb=availmemGb,
                     quiet=quiet,
                     extBIC=extBIC,
-                    gamma=gamma)
+                    gamma=gamma,
+                    geno=geno,
+                    pheno=pheno,
+                    map=map,
+                    Zmat=Zmat)
   }
 return(sigres)
 }
